==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Krejt shkronjat</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Përdorues</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Të parapëlqyera</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktive</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kinezçe</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Të llojit Monospace</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Kartelë e dëmtuar</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>I njëjti version i instaluar</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Shkronja Sistemi</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Shkronja</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Shkronjat %1 u instaluan</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Shkronjat %1 u instaluan</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Jeni i sigurt se doni të fshihet ky lloj shkronjash?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ky lloj shkronjash s’do të jetë i passhëm për aplikacionet</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Këto lloje shkronjash s’do të jenë të passhme për aplikacionet</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>%1 llojet e tjera të shkronjave të sistemit s’mund të fshihen</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Lloji &quot;%1&quot; i shkronjave në përdorim s’mund të fshihet</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>%1 llojet e tjera të shkronjave të sistemit dhe shkronjat &quot;%2&quot;s’mund të fshihen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Jeni i sigurt se doni të fshihen %1 lloj(e) shkronjash?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Po fshihen shkronja, ju lutemi, pritni…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verifikim Shkronjash</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dalje</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Vazhdo</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>S’ka shkronja për instalim</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Mos i lini ëndrrat tuaja të mbeten thjesht ëndrra</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Të dhëna elementare</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloj</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Përshkrim</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Të panjohura</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Emër i plotë</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Emër Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Shenjë tregtare</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Përgjegjës Shkronjash</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Përgjegjësi i Shkronjave i ndihmon përdoruesit të instalojnë dhe administrojnë shkronja.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Po ngarkohen shkronjat, ju lutemi, pritni…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Lloji i shkronjave u eksportuan në desktopin tuaj</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 lloje shkronjash u eksportuan në desktopin tuaj</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>S’u arrit të eksportohej 1 lloj shkronjash. S’ka hapësirë të mjaftueshme në disk.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>S’u arrit të eksportoheshin %1 lloje shkronjash. S’ka hapësirë të mjaftueshme në disk.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Shtoni shkronja</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivizoji</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Çaktivizoji</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Vëre si të parapëlqyer</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Hollësi</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe te përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportoji</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>të çaktivizuara</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Shkronjat janë çaktivizuar</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>Shkronjat %1 janë në përdorim, s’mund të çaktivizohen</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>S’mund të çaktivizoni shkronja sistemi dhe shkronja që janë në përdorim</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>S’mund të çaktivizoni shkronja sistemi</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Për disa lloje shkronjash nuk lejohet çaktivizimi</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalo Shkronja</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Po verifikohet…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Të panjohura</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Kartelë e dëmtuar</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Të instaluara</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Jo të Instaluara</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalo Shkronja</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>S’ka përfundime kërkimi</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>S’ka shkronja</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Tasti Page Up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Tasti Page Down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Shtoni shkronja</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Vëre si të parapëlqyer</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Të dhëna shkronjash</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Tekst prove</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Kartelë e dëmtuar</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Krejt shkronjat</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Përdorues</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Të parapëlqyera</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktive</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kinezçe</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Të llojit Monospace</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 është një familje shkronjash, nëse vazhdoni, do të fshihen krejt shkronjat në të</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 është një familje shkronjash, nëse vazhdoni, krejt shkronjat në të do të aktivizohen</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 është një familje shkronjash, nëse vazhdoni, krejt shkronjat në të do të çaktivizohen</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Aktivizoji</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Çaktivizoji</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Aplikoje te krejt familjet e përzgjedhura të shkronjave</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Kartelë e dëmtuar</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>I njëjti version i instaluar</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Shkronja Sistemi</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Shkronjat %1 u instaluan</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Shkronjat %1 u instaluan</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>S’u arrit të instalohet %1 lloj shkronjash. S’ka hapësirë të mjaftueshme në disk.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>S’u arrit të instalohen %1 lloje shkronjash. S’ka hapësirë të mjaftueshme në disk.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ky lloj shkronjash s’do të jetë i passhëm për aplikacionet</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Këto lloje shkronjash s’do të jenë të passhme për aplikacionet</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>%1 llojet e tjera të shkronjave të sistemit s’mund të fshihen</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Lloji &quot;%1&quot; i shkronjave në përdorim s’mund të fshihet</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>%1 llojet e tjera të shkronjave të sistemit dhe shkronjat &quot;%2&quot;s’mund të fshihen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Jeni i sigurt se doni të fshihen %1 lloj(e) shkronjash?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Po fshihen shkronja, ju lutemi, pritni…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verifikim Shkronjash</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>S’ka shkronja për instalim</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Dalje</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Vazhdo</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Të dhëna elementare</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloj</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Përshkrim</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Të panjohura</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Emër i plotë</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Emër Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Shenjë tregtare</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Përgjegjës Shkronjash</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Përgjegjësi i Shkronjave i ndihmon përdoruesit të instalojnë dhe administrojnë shkronja.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Po ngarkohen shkronjat, ju lutemi, pritni…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Lloji i shkronjave u eksportuan në desktopin tuaj</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 lloje shkronjash u eksportuan në desktopin tuaj</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>S’u arrit të eksportohej 1 lloj shkronjash. S’ka hapësirë të mjaftueshme në disk.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>S’u arrit të eksportoheshin %1 lloje shkronjash. S’ka hapësirë të mjaftueshme në disk.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Shtoni shkronja</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivizoji</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Çaktivizoji</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Vëre si të parapëlqyer</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Hollësi</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe te përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportoji</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>të çaktivizuara</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Shkronjat janë çaktivizuar</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>Shkronjat %1 janë në përdorim, s’mund të çaktivizohen</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>S’mund të çaktivizoni shkronja sistemi dhe shkronja që janë në përdorim</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>S’mund të çaktivizoni shkronja sistemi</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalo Shkronja</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Po verifikohet…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Të panjohura</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Kartelë e dëmtuar</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Të instaluara</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Jo të Instaluara</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalo Shkronja</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>S’ka përfundime kërkimi</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>S’ka shkronja</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Tasti Page Up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Tasti Page Down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Shtoni shkronja</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Vëre si të parapëlqyer</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Të dhëna shkronjash</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Tekst prove</translation>
    </message>
</context>
</TS>
